package org.postgresql.jdbc2;

import java.math.BigDecimal;
import java.util.Calendar;

import java.sql.Statement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.SQLWarning;

import java.sql.Blob;
import java.sql.ResultSetMetaData;
import java.sql.Array;
import java.sql.Clob;
import java.sql.Ref;
import java.sql.PreparedStatement;


public class WrappedPreparedStatement extends WrappedStatement implements PreparedStatement  {

    private PreparedStatement ps;
    public WrappedPreparedStatement(PreparedStatement stmt, PostgresqlPooledConnection ppc){
        super(stmt,ppc);
        this.ps = stmt;
    }
    
    public ResultSet executeQuery() throws SQLException{
        try{
            return ps.executeQuery();
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public int executeUpdate() throws SQLException{
        try{
            return ps.executeUpdate();
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setNull(int parameterIndex, int sqlType) throws SQLException{
        try{
            ps.setNull( parameterIndex,  sqlType);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setBoolean(int parameterIndex, boolean x) throws SQLException{
        try{
            ps.setBoolean( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setByte(int parameterIndex, byte x) throws SQLException{
        try{
            ps.setByte( parameterIndex, x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setShort(int parameterIndex, short x) throws SQLException{
        try{
            ps.setShort( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setInt(int parameterIndex, int x) throws SQLException{
        try{
            ps.setInt( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setLong(int parameterIndex, long x) throws SQLException{
        try{
            ps.setLong( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setFloat(int parameterIndex, float x) throws SQLException{
        try{
            ps.setFloat( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setDouble(int parameterIndex, double x) throws SQLException{
        try{
            ps.setDouble( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setBigDecimal(int parameterIndex, BigDecimal x) throws SQLException{
        try{
            ps.setBigDecimal( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setString(int parameterIndex, String x) throws SQLException{
        try{
            ps.setString( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setBytes(int parameterIndex, byte x[]) throws SQLException{
        try{
            ps.setBytes( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setDate(int parameterIndex, java.sql.Date x) throws SQLException{
        try{
            ps.setDate( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setTime(int parameterIndex, java.sql.Time x) throws SQLException{
        try{
            ps.setTime( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setTimestamp(int parameterIndex, java.sql.Timestamp x) throws SQLException{
        try{
            ps.setTimestamp( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setAsciiStream(int parameterIndex, java.io.InputStream x, int length) throws SQLException{
        try{
            ps.setAsciiStream( parameterIndex, x, length);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setUnicodeStream(int parameterIndex, java.io.InputStream x,  int length) throws SQLException{
        try{
            ps.setUnicodeStream( parameterIndex,  x,  length);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setBinaryStream(int parameterIndex, java.io.InputStream x, int length) throws SQLException{
        try{
            ps.setBinaryStream( parameterIndex,  x,  length);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void clearParameters() throws SQLException{
        try{
            ps.clearParameters();
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void setObject(int parameterIndex, Object x, int targetSqlType, int scale) throws SQLException{
        try{
            ps.setObject( parameterIndex,  x,  targetSqlType,  scale);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

   
    public void setObject(int parameterIndex, Object x, int targetSqlType) throws SQLException{
        try{
            ps.setObject( parameterIndex,  x,  targetSqlType);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setObject(int parameterIndex, Object x) throws SQLException{
        try{
            ps.setObject( parameterIndex,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public boolean execute() throws SQLException{
        try{
            return ps.execute();
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void addBatch() throws SQLException{
        try{
            ps.addBatch();
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setCharacterStream(int parameterIndex,java.io.Reader reader, int length) throws SQLException{
        try{
            ps.setCharacterStream( parameterIndex, reader,  length);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setRef (int i, Ref x) throws SQLException{
        try{
            ps.setRef ( i,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setBlob (int i, Blob x) throws SQLException{
        try{
            ps.setBlob ( i,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setClob (int i, Clob x) throws SQLException{
        try{
            ps.setClob ( i,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setArray (int i, Array x) throws SQLException{
        try{
            ps.setArray ( i,  x);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public ResultSetMetaData getMetaData() throws SQLException{
        try{
            return ps.getMetaData();
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setDate(int parameterIndex, java.sql.Date x, Calendar cal)throws SQLException{
        try{
            ps.setDate( parameterIndex,  x,  cal);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setTime(int parameterIndex, java.sql.Time x, Calendar cal) throws SQLException{
        try{
            ps.setTime( parameterIndex, x,  cal);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setTimestamp(int parameterIndex, java.sql.Timestamp x, Calendar cal) throws SQLException{
        try{
            ps.setTimestamp( parameterIndex, x, cal);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    
    public void setNull (int paramIndex, int sqlType, String typeName) throws SQLException{
        try{
            ps.setNull ( paramIndex,  sqlType,  typeName);
        }catch(SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }
}










