package org.postgresql.jdbc2;

import java.math.BigDecimal;
import java.util.Calendar;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.Statement;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.Blob;
import java.sql.ResultSetMetaData;
import java.sql.Array;
import java.sql.Clob;
import java.sql.Ref;

public class WrappedResultSet implements ResultSet {

    private ResultSet rset;
    private PostgresqlPooledConnection ppc;
    private WrappedStatement stmt;
    public WrappedResultSet(ResultSet rset, WrappedStatement s, PostgresqlPooledConnection ppc){
        this.rset = rset;
        this.ppc  = ppc;
        this.stmt = stmt;
    }

    public boolean next() throws SQLException{
        try {
            return rset.next();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }

    }

    
    public void close() throws SQLException{
        try {
            rset.close();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }

    }

    
    public boolean wasNull() throws SQLException{
        try {
            return rset.wasNull();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }

    }
   
    
    public String getString(int columnIndex) throws SQLException{
        try {
            return rset.getString( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public boolean getBoolean(int columnIndex) throws SQLException{
        try {
            return rset.getBoolean( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public byte getByte(int columnIndex) throws SQLException{
        try {
            return rset.getByte( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public short getShort(int columnIndex) throws SQLException{
        try {
            return rset.getShort( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public int getInt(int columnIndex) throws SQLException{
        try {
            return rset.getInt( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public long getLong(int columnIndex) throws SQLException{
        try {
            return rset.getLong( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public float getFloat(int columnIndex) throws SQLException{
        try {
            return rset.getFloat( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public double getDouble(int columnIndex) throws SQLException{
        try {
            return rset.getDouble( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public BigDecimal getBigDecimal(int columnIndex, int scale) throws SQLException{
        try {
            return rset.getBigDecimal( columnIndex,  scale);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
    
    
    public byte[] getBytes(int columnIndex) throws SQLException{
        try {
            return rset.getBytes( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
    
    
    public java.sql.Date getDate(int columnIndex) throws SQLException{
        try {
            return rset.getDate(columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
    
    
    public java.sql.Time getTime(int columnIndex) throws SQLException{
        try {
            return rset.getTime( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.sql.Timestamp getTimestamp(int columnIndex) throws SQLException{
        try {
            return rset.getTimestamp( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.io.InputStream getAsciiStream(int columnIndex) throws SQLException{
        try {
            return rset.getAsciiStream( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.io.InputStream getUnicodeStream(int columnIndex) throws SQLException{
        try {
            return rset.getUnicodeStream( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.io.InputStream getBinaryStream(int columnIndex) throws SQLException{
        try {
            return rset.getBinaryStream( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public String getString(String columnName) throws SQLException{
        try {
            return rset.getString( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public boolean getBoolean(String columnName) throws SQLException{
        try {
            return rset.getBoolean( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public byte getByte(String columnName) throws SQLException{
        try {
            return rset.getByte( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public short getShort(String columnName) throws SQLException{
        try {
            return rset.getShort( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public int getInt(String columnName) throws SQLException{
        try {
            return rset.getInt( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public long getLong(String columnName) throws SQLException{
        try {
            return rset.getLong( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public float getFloat(String columnName) throws SQLException{
        try {
            return rset.getFloat( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public double getDouble(String columnName) throws SQLException{
        try {
            return rset.getDouble( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public BigDecimal getBigDecimal(String columnName, int scale) throws SQLException{
        try {
            return rset.getBigDecimal( columnName,  scale);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public byte[] getBytes(String columnName) throws SQLException{
        try {
            return rset.getBytes( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
    
    
    public java.sql.Date getDate(String columnName) throws SQLException{
        try {
            return rset.getDate( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
    
    
    public java.sql.Time getTime(String columnName) throws SQLException{
        try {
            return rset.getTime( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
    
    
    public java.sql.Timestamp getTimestamp(String columnName) throws SQLException{
        try {
            return rset.getTimestamp( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
    
    
    public java.io.InputStream getAsciiStream(String columnName) throws SQLException{
        try {
            return rset.getAsciiStream( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
    
    
    public java.io.InputStream getUnicodeStream(String columnName) throws SQLException{
        try {
            return rset.getUnicodeStream( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
    
    
    public java.io.InputStream getBinaryStream(String columnName) throws SQLException{
        try {
            return rset.getBinaryStream( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public SQLWarning getWarnings() throws SQLException{
        try {
            return rset.getWarnings();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void clearWarnings() throws SQLException{
        try {
            rset.clearWarnings();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public String getCursorName() throws SQLException{
        try {
            return rset.getCursorName();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public ResultSetMetaData getMetaData() throws SQLException{
        try {
            return rset.getMetaData();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Object getObject(int columnIndex) throws SQLException{
        try {
            return rset.getObject( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Object getObject(String columnName) throws SQLException{
        try {
            return rset.getObject( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public int findColumn(String columnName) throws SQLException{
        try {
            return rset.findColumn( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.io.Reader getCharacterStream(int columnIndex) throws SQLException{
        try {
            return rset.getCharacterStream( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.io.Reader getCharacterStream(String columnName) throws SQLException{
        try {
            return rset.getCharacterStream( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public BigDecimal getBigDecimal(int columnIndex) throws SQLException{
        try {
            return rset.getBigDecimal( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public BigDecimal getBigDecimal(String columnName) throws SQLException{
        try {
            return rset.getBigDecimal( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public boolean isBeforeFirst() throws SQLException{
        try {
            return rset.isBeforeFirst();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
      
    
    public boolean isAfterLast() throws SQLException{
        try {
            return rset.isAfterLast();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
 
    
    public boolean isFirst() throws SQLException{
        try {
            return rset.isFirst();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
 
    
    public boolean isLast() throws SQLException{
        try {
            return rset.isLast();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void beforeFirst() throws SQLException{
        try {
            rset.beforeFirst();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void afterLast() throws SQLException{
        try {
            rset.afterLast();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public boolean first() throws SQLException{
        try {
            return rset.first();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public boolean last() throws SQLException{
        try {
            return rset.last();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public int getRow() throws SQLException{
        try {
            return rset.getRow();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public boolean absolute( int row ) throws SQLException{
        try {
            return rset.absolute(  row );
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public boolean relative( int rows ) throws SQLException{
        try {
            return rset.relative(  rows );
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public boolean previous() throws SQLException{
        try {
            return rset.previous();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void setFetchDirection(int direction) throws SQLException{
        try {
            rset.setFetchDirection( direction);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public int getFetchDirection() throws SQLException{
        try {
            return rset.getFetchDirection();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void setFetchSize(int rows) throws SQLException{
        try {
            rset.setFetchSize( rows);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public int getFetchSize() throws SQLException{
        try {
            return rset.getFetchSize();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    public int getType() throws SQLException{
        try {
            return rset.getType();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public int getConcurrency() throws SQLException{
        try {
            return rset.getConcurrency();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    public boolean rowUpdated() throws SQLException{
        try {
            return rset.rowUpdated();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public boolean rowInserted() throws SQLException{
        try {
            return rset.rowInserted();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
   
    
    public boolean rowDeleted() throws SQLException{
        try {
            return rset.rowDeleted();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateNull(int columnIndex) throws SQLException{
        try {
            rset.updateNull( columnIndex);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateBoolean(int columnIndex, boolean x) throws SQLException{
        try {
            rset.updateBoolean( columnIndex, x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateByte(int columnIndex, byte x) throws SQLException{
        try {
            rset.updateByte( columnIndex,x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateShort(int columnIndex, short x) throws SQLException{
        try {
            rset.updateShort( columnIndex, x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateInt(int columnIndex, int x) throws SQLException{
        try {
            rset.updateInt( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateLong(int columnIndex, long x) throws SQLException{
        try {
            rset.updateLong( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateFloat(int columnIndex, float x) throws SQLException{
        try {
            rset.updateFloat( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateDouble(int columnIndex, double x) throws SQLException{
        try {
            rset.updateDouble( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateBigDecimal(int columnIndex, BigDecimal x) throws SQLException{
        try {
            rset.updateBigDecimal( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateString(int columnIndex, String x) throws SQLException{
        try {
            rset.updateString( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateBytes(int columnIndex, byte x[]) throws SQLException{
        try {
            rset.updateBytes( columnIndex, x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateDate(int columnIndex, java.sql.Date x) throws SQLException{
        try {
            rset.updateDate( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateTime(int columnIndex, java.sql.Time x) throws SQLException{
        try {
            rset.updateTime( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateTimestamp(int columnIndex, java.sql.Timestamp x) throws SQLException{
        try {
            rset.updateTimestamp( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateAsciiStream(int columnIndex,  java.io.InputStream x,  int length) throws SQLException{
        try {
            rset.updateAsciiStream( columnIndex,   x,  length);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateBinaryStream(int columnIndex, java.io.InputStream x, int length) throws SQLException{
        try {
            rset.updateBinaryStream( columnIndex,  x,  length);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateCharacterStream(int columnIndex, java.io.Reader x,  int length) throws SQLException{
        try {
            rset.updateCharacterStream( columnIndex,  x,   length);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateObject(int columnIndex, Object x, int scale) throws SQLException{
        try {
            rset.updateObject( columnIndex,  x,  scale);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateObject(int columnIndex, Object x) throws SQLException{
        try {
            rset.updateObject( columnIndex,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateNull(String columnName) throws SQLException{
        try {
            rset.updateNull( columnName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateBoolean(String columnName, boolean x) throws SQLException{
        try {
            rset.updateBoolean( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateByte(String columnName, byte x) throws SQLException{
        try {
            rset.updateByte( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateShort(String columnName, short x) throws SQLException{
        try {
            rset.updateShort( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateInt(String columnName, int x) throws SQLException{
        try {
            rset.updateInt( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateLong(String columnName, long x) throws SQLException{
        try {
            rset.updateLong( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateFloat(String columnName, float x) throws SQLException{
        try {
            rset.updateFloat( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateDouble(String columnName, double x) throws SQLException{
        try {
            rset.updateDouble( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateBigDecimal(String columnName, BigDecimal x) throws SQLException{
        try {
            rset.updateBigDecimal( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateString(String columnName, String x) throws SQLException{
        try {
            rset.updateString( columnName, x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateBytes(String columnName, byte x[]) throws SQLException{
        try {
            rset.updateBytes( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateDate(String columnName, java.sql.Date x) throws SQLException{
        try {
            rset.updateDate( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateTime(String columnName, java.sql.Time x) throws SQLException{
        try {
            rset.updateTime( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateTimestamp(String columnName, java.sql.Timestamp x) throws SQLException{
        try {
            rset.updateTimestamp( columnName,  x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateAsciiStream(String columnName,  java.io.InputStream x, int length) throws SQLException{
        try {
            rset.updateAsciiStream( columnName,   x,  length);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateBinaryStream(String columnName,  java.io.InputStream x, int length) throws SQLException{
        try {
            rset.updateBinaryStream( columnName,   x,  length);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateCharacterStream(String columnName, java.io.Reader reader, int length) throws SQLException{
        try {
            rset.updateCharacterStream( columnName,  reader,  length);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateObject(String columnName, Object x, int scale) throws SQLException{
        try {
            rset.updateObject(columnName,x,scale);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateObject(String columnName, Object x) throws SQLException{
        try {
            rset.updateObject(columnName,x);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void insertRow() throws SQLException{
        try {
            rset.insertRow();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void updateRow() throws SQLException{
        try {
            rset.updateRow();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void deleteRow() throws SQLException{
        try {
            rset.deleteRow();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void refreshRow() throws SQLException{
        try {
            rset.refreshRow();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void cancelRowUpdates() throws SQLException{
        try {
            rset.cancelRowUpdates();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void moveToInsertRow() throws SQLException{
        try {
            rset.moveToInsertRow();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public void moveToCurrentRow() throws SQLException{
        try {
            rset.moveToCurrentRow();
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Statement getStatement() throws SQLException{
        return stmt;
    }

    
    public Object getObject(int i, java.util.Map map) throws SQLException{
        try {
            return rset.getObject( i,  map);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Ref getRef(int i) throws SQLException{
        try {
            return rset.getRef( i);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Blob getBlob(int i) throws SQLException{
        try {
            return rset.getBlob( i);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Clob getClob(int i) throws SQLException{
        try {
            return rset.getClob( i);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Array getArray(int i) throws SQLException{
        try {
            return rset.getArray( i);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Object getObject(String colName, java.util.Map map) throws SQLException{
        try {
            return rset.getObject( colName,  map);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Ref getRef(String colName) throws SQLException{
        try {
            return rset.getRef( colName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Blob getBlob(String colName) throws SQLException{
        try {
            return rset.getBlob( colName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Clob getClob(String colName) throws SQLException{
        try {
            return rset.getClob( colName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public Array getArray(String colName) throws SQLException{
        try {
            return rset.getArray( colName);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.sql.Date getDate(int columnIndex, Calendar cal) throws SQLException{
        try {
            return rset.getDate( columnIndex, cal);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.sql.Date getDate(String columnName, Calendar cal) throws SQLException{
        try {
            return rset.getDate( columnName,  cal);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.sql.Time getTime(int columnIndex, Calendar cal) throws SQLException{
        try {
            return rset.getTime( columnIndex,  cal);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.sql.Time getTime(String columnName, Calendar cal) throws SQLException{
        try {
            return rset.getTime( columnName,  cal);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.sql.Timestamp getTimestamp(int columnIndex, Calendar cal) throws SQLException{
        try {
            return rset.getTimestamp( columnIndex,  cal);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }

    
    public java.sql.Timestamp getTimestamp(String columnName, Calendar cal) throws SQLException{
        try {
            return rset.getTimestamp( columnName,  cal);
        } catch (SQLException e){
            ppc.setException(e);
            throw e;
        }
    }
}










