package org.postgresql.jdbc2;

import java.sql.Statement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.SQLWarning;

public class WrappedStatement implements Statement{

    private   Statement stmt;
    protected PostgresqlPooledConnection ppc;
    public WrappedStatement(Statement stmt, PostgresqlPooledConnection ppc){
        this.stmt = stmt;
        this.ppc  = ppc;
    }
    

    public ResultSet executeQuery(String sql) throws SQLException{
        try {
            return new WrappedResultSet(stmt.executeQuery(sql),this,ppc);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }
    
    public int executeUpdate(String sql) throws SQLException{
        try {
            return stmt.executeUpdate(sql);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void close() throws SQLException{
        try {
            stmt.close();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public int getMaxFieldSize() throws SQLException{
        try {
            return stmt.getMaxFieldSize();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void setMaxFieldSize(int max) throws SQLException{
        try {
            stmt.setMaxFieldSize(max);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public int getMaxRows() throws SQLException{
        try {
            return stmt.getMaxRows();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void setMaxRows(int max) throws SQLException{
        try {
            stmt.setMaxRows(max);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void setEscapeProcessing(boolean enable) throws SQLException{
        try {
            stmt.setEscapeProcessing(enable);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public int getQueryTimeout() throws SQLException{
        try {
            return stmt.getQueryTimeout();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void setQueryTimeout(int seconds) throws SQLException{
        try {
            stmt.setQueryTimeout(seconds);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void cancel() throws SQLException{
        try {
            stmt.cancel();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public SQLWarning getWarnings() throws SQLException{
        try {
            return stmt.getWarnings();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void clearWarnings() throws SQLException{
        try {
            stmt.clearWarnings();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void setCursorName(String name) throws SQLException{
        try {
            stmt.setCursorName(name);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }
	
    public boolean execute(String sql) throws SQLException{
        try {
            return stmt.execute(sql);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }
	
    public ResultSet getResultSet() throws SQLException{
        try {
            return new WrappedResultSet(stmt.getResultSet(),this,ppc);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

public int getUpdateCount() throws SQLException{
        try {
            return stmt.getUpdateCount();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public boolean getMoreResults() throws SQLException{
        try {
            return stmt.getMoreResults();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }


    public void setFetchDirection(int direction) throws SQLException{
        try {
            stmt.setFetchDirection(direction);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public int getFetchDirection() throws SQLException{
        try {
            return stmt.getFetchDirection();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void setFetchSize(int rows) throws SQLException{
        try {
            stmt.setFetchSize(rows);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }
  
    public int getFetchSize() throws SQLException{
        try {
            return stmt.getFetchSize();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public int getResultSetConcurrency() throws SQLException{
        try {
            return stmt.getResultSetConcurrency();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public int getResultSetType()  throws SQLException{
        try {
            return stmt.getResultSetType();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void addBatch( String sql ) throws SQLException{
        try {
            stmt.addBatch(sql);
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public void clearBatch() throws SQLException{
        try {
            stmt.clearBatch();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public int[] executeBatch() throws SQLException{
        try {
            return stmt.executeBatch();
        }catch (SQLException e){
            ppc.setException(e);
            throw(e);
        }
    }

    public java.sql.Connection getConnection()  throws SQLException{
        return ppc;
    }
}	
